#
# spec file for package polkit-qt-1
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor qt6%{nil}
%if "%flavor" == "%{nil}"
%define pkg_suffix -qt
ExclusiveArch:  do-not-build
%endif
%if "%flavor" == "qt5"
%define pkg_suffix -qt5
%define qt5 1
%define qt5_version 5.5.0
%endif
%if "%flavor" == "qt6"
%define pkg_suffix -qt6
%define qt6 1
%define qt6_version 6.5.0
%endif

%bcond_without released
%define rname polkit-qt-1
Name:           polkit%{pkg_suffix}-1
Version:        0.200.0
Release:        1.3
Summary:        PolicyKit Library Qt Bindings
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/polkit-qt-1/%{rname}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/polkit-qt-1/%{rname}-%{version}.tar.xz.sig
Source2:        %{rname}.keyring
%endif
BuildRequires:  pkgconfig
BuildRequires:  polkit-devel
%if 0%{?qt5}
BuildRequires:  extra-cmake-modules
BuildRequires:  kf5-filesystem
BuildRequires:  cmake(Qt5Core) >= %{qt5_version}
BuildRequires:  cmake(Qt5DBus) >= %{qt5_version}
BuildRequires:  cmake(Qt5Widgets) >= %{qt5_version}
%endif
%if 0%{?qt6}
BuildRequires:  kf6-extra-cmake-modules
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
%endif

%description
Polkit-qt-1 aims to make it easy for Qt developers to take advantage of
PolicyKit API. It is a convenience wrapper around QAction and
QAbstractButton that lets you integrate those two components easily
with PolicyKit.

%package -n libpolkit%{pkg_suffix}-1-1
Summary:        PolicyKit Library Qt Bindings

%description -n libpolkit%{pkg_suffix}-1-1
Polkit-qt aims to make it easy for Qt developers to take advantage of
PolicyKit API. It is a convenience wrapper around QAction and
QAbstractButton that lets you integrate those two components easily
with PolicyKit.

%package -n libpolkit%{pkg_suffix}-1-devel
Summary:        PolicyKit Library Qt Bindings
Requires:       libpolkit%{pkg_suffix}-1-1 = %{version}
Requires:       polkit-devel

%description -n libpolkit%{pkg_suffix}-1-devel
Polkit-qt aims to make it easy for Qt developers to take advantage of
PolicyKit API. It is a convenience wrapper around QAction and
QAbstractButton that lets you integrate those two components easily
with PolicyKit.

%prep
%autosetup -n %{rname}-%{version}

%build
%if 0%{?qt5}
%cmake_kf5 -d build
%cmake_build
%endif

%if 0%{?qt6}
%cmake_kf6 -DQT_MAJOR_VERSION:STRING=6
%kf6_build
%endif

%install
%if 0%{?qt5}
%kf5_makeinstall -C build
%endif

%if 0%{?qt6}
%kf6_install
%endif

%ldconfig_scriptlets -n libpolkit%{pkg_suffix}-1-1

%files -n libpolkit%{pkg_suffix}-1-1
%license LICENSES/*
%doc README
%if 0%{?qt5}
%{_kf5_libdir}/libpolkit-qt5-gui-1.so.*
%{_kf5_libdir}/libpolkit-qt5-core-1.so.*
%{_kf5_libdir}/libpolkit-qt5-agent-1.so.*
%endif
%if 0%{?qt6}
%{_kf6_libdir}/libpolkit-qt6-gui-1.so.*
%{_kf6_libdir}/libpolkit-qt6-core-1.so.*
%{_kf6_libdir}/libpolkit-qt6-agent-1.so.*
%endif

%files -n libpolkit%{pkg_suffix}-1-devel
%{_includedir}/polkit%{pkg_suffix}-1/
%if 0%{?qt5}
%{_kf5_libdir}/pkgconfig/polkit-qt5-*.pc
%{_kf5_libdir}/libpolkit-qt5-gui-1.so
%{_kf5_libdir}/libpolkit-qt5-core-1.so
%{_kf5_libdir}/libpolkit-qt5-agent-1.so
%{_kf5_libdir}/cmake/PolkitQt5-1/
%endif
%if 0%{?qt6}
%{_kf6_pkgconfigdir}/polkit-qt6-*.pc
%{_kf6_libdir}/libpolkit-qt6-gui-1.so
%{_kf6_libdir}/libpolkit-qt6-core-1.so
%{_kf6_libdir}/libpolkit-qt6-agent-1.so
%{_kf6_libdir}/cmake/PolkitQt6-1/
%endif

%changelog
* Thu Feb 22 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 0.200.0:
  * New bugfix release
- Changes since 0.175.0:
  * Increase version to 0.200.0
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 0.175.0 (0.200.0-alpha):
  * Increase version to 0.175.0
  * Remove unused CPack parts
  * Remove unused variable
  * fix: memory leak
  * Change CMake code to enable building against Qt 5 or 6
  * Unexport nested private classes
  * Require glib 2.36 and remove "do nothing" g_type_init
  * Change installed .cmake and .pc files to contain realtive paths
  * Add polkit error
* Wed Sep 15 2021 Christophe Giboudeaux <christophe@krop.fr>
- Drop the unneeded baselibs.conf.
* Wed Jun 23 2021 Wolfgang Bauer <wbauer@tmo.at>
- New upstream release 0.114.0
- Changes since 0.113.0:
  * Use feature_summary()
  * Drop PolkitQt1::version*() API declaration, never implemented
  * Use target_sources to directly set sources instead of helper vars
  * Include headers in example & test like external consumer would
  * Set include dirs for linking libraries during build by target interface
  * Generate version & config file in core build dir
  * Use individual export headers/macros per each library
  * Remove outdated template FindPolkitQt.cmake
  * Remove module prefix from Qt includes in public headers
  * Link polkit-qt-test to agent lib target, an include is used
  * Remove module prefix from Qt includes of non-public headers
  * Remove unused include
  * Remove unneeded/unused include_directories
  * Use more override
  * Use more nullptr
  * Port away from legacy LINK_PUBLIC & LINK_PRIVATE
  * Fully qualify slot argument
  * Use QStringLiteral
  * Convert license statements to SPDX expressions
  * Remove unused cmake macro files
  * Enable CMAKE_AUTOUIC and CMAKE_AUTORCC
  * Let cmake set the C++ standard
  * Port from Q_ENUMS to Q_ENUM
  * Make use of PkgConfig to find dependencies
  * Use Q_DECLARE_OPERATORS_FOR_FLAGS in same namespace as flags definition
  * Use more nullptr
  * API dox: reference KDE Frameworks, no longer KDE Development Platform
  * Support API documentation generation with kapidox
  * Make it compile without deprecated method
- Use %%cmake_build instead of %%make_jobs for compiling
* Tue Aug 27 2019 Luca Beltrame <lbeltrame@kde.org>
- New upstream release 0.113.0
- Changes since 0.112.0:
  * Bump version for release
  * Don't set version numbers as INT cache entries
  * Move cmake_minimum_required to the top of CMakeLists.txt
  * Remove support for Qt4
  * Remove unneded documentation
  * authority: add support for passing details to polkit
  * Fix typo in comments
  * Add .arcconfig
  * Remove unused file
  * polkitqtlistener.cpp - pedantic
  * Fix build with -DBUILD_TEST=TRUE
  * Allow compilation with older polkit versions
  * Fix compilation with Qt5.6
  * Drop use of deprecated Qt functions REVIEW: 126747
  * Add wrapper for polkit_system_bus_name_get_user_sync
  * Add .reviewboardrc
  * Fix QDBusArgument assertion
  * fix build with Qt4, which doesn't have QStringLiteral. so use QString instead.
  * do not use global static systembus instance
- Dropped patch, now upstream:
  * do-not-use-global-static-systembus-instance.patch
- Run spec-cleaner
* Wed Aug 13 2014 hrvoje.senjan@gmail.com
- Added do-not-use-global-static-systembus-instance.patch from
  upstream, fixes crash on DBus disconnect
* Thu Jul 10 2014 hrvoje.senjan@gmail.com
- Update to 0.112.0
  * Qt5 support
  * Update deprecated methods to latest Polkit API
- Drop patches merged upstream: fixed-reference-counting-of-GObjects.patch,
  fixed-GCancellable-handling-in-PolkitQtListener.patch and
  qt5-support.patch
* Wed Jun 18 2014 hrvoje.senjan@gmail.com
- Add license to %%doc
* Mon Apr 14 2014 hrvoje.senjan@gmail.com
- Activate polkit-qt5-1 package
